==> coin_0.6-3.tar.gz: coin/man/initialize-methods.Rd <==
\name{initialize-methods}
\docType{methods}
\alias{initialize}
\alias{initialize-methods}
\alias{initialize,ANY-method}
\alias{initialize,traceable-method}
\alias{initialize,signature-method}
\alias{initialize,environment-method}
\alias{initialize,ModelEnv-method}
\alias{initialize,CovarianceMatrix-method}
\alias{initialize,Variance-method}
\alias{initialize,IndependenceTestProblem-method}
\alias{initialize,IndependenceTestStatistic-method}
\alias{initialize,ScalarIndependenceTestStatistic-method}
\alias{initialize,MaxTypeIndependenceTestStatistic-method}
\alias{initialize,QuadTypeIndependenceTestStatistic-method}
\title{ Methods for Function initialize in Package `coin' }
\description{
  Methods for function \code{initialize} in package \pkg{coin} 
}
\section{Methods}{
\describe{

\item{.Object = "ANY"}{ ~~describe this method here }

\item{.Object = "traceable"}{ ~~describe this method here }

\item{.Object = "signature"}{ ~~describe this method here }

\item{.Object = "environment"}{ ~~describe this method here }

\item{.Object = "ModelEnv"}{ ~~describe this method here }

\item{.Object = "IndependenceProblem"}{ ~~describe this method here }

\item{.Object = "IndependenceTestProblem"}{ ~~describe this method here }

\item{.Object = "IndependenceTestStatistic"}{ ~~describe this method here }

\item{.Object = "ScalarIndependenceTestStatistic"}{ ~~describe this method here }

\item{.Object = "MaxTypeIndependenceTestStatistic"}{ ~~describe this method here }

\item{.Object = "QuadTypeIndependenceTestStatistic"}{ ~~describe this method here }

\item{.Object = "SymmetryProblem"}{ ~~describe this method here }
}}
\keyword{methods}

==> coin_1.0-3.tar.gz: coin/man/initialize-methods.Rd <==
\name{initialize-methods}
\docType{methods}
\alias{initialize}
\alias{initialize-methods}
\alias{initialize,ANY-method}
\alias{initialize,traceable-method}
\alias{initialize,signature-method}
\alias{initialize,environment-method}
\alias{initialize,ModelEnv-method}
\alias{initialize,CovarianceMatrix-method}
\alias{initialize,Variance-method}
\alias{initialize,IndependenceLinearStatistic-method}
\alias{initialize,IndependenceTestStatistic-method}
\title{ Methods for Function initialize in Package `coin' }
\description{
  Methods for function \code{initialize} in package \pkg{coin} 
}
\section{Methods}{
\describe{

\item{.Object = "ANY"}{ ~~describe this method here }

\item{.Object = "traceable"}{ ~~describe this method here }

\item{.Object = "signature"}{ ~~describe this method here }

\item{.Object = "environment"}{ ~~describe this method here }

\item{.Object = "ModelEnv"}{ ~~describe this method here }

\item{.Object = "IndependenceProblem"}{ ~~describe this method here }

\item{.Object = "IndependenceTestProblem"}{ ~~describe this method here }

\item{.Object = "IndependenceTestStatistic"}{ ~~describe this method here }

\item{.Object = "IndependenceLinearStatistic"}{ ~~describe this method here }

\item{.Object = "ScalarIndependenceTestStatistic"}{ ~~describe this method here }

\item{.Object = "MaxTypeIndependenceTestStatistic"}{ ~~describe this method here }

\item{.Object = "QuadTypeIndependenceTestStatistic"}{ ~~describe this method here }

\item{.Object = "SymmetryProblem"}{ ~~describe this method here }
}}
\keyword{methods}
